# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKThresholdingPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkBinaryThresholdImageFilterPython
else:
    import _itkBinaryThresholdImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.pyBasePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkCovariantVectorPython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.vnl_matrix_fixedPython
import itk.itkPointPython
import itk.itkSimpleDataObjectDecoratorPython
import itk.itkRGBPixelPython
import itk.itkArrayPython
import itk.itkRGBAPixelPython
import itk.itkInPlaceImageFilterAPython
import itk.itkImageToImageFilterAPython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageToImageFilterBPython

def itkBinaryThresholdImageFilterIF2IF2_Superclass_New():
    return itkBinaryThresholdImageFilterIF2IF2_Superclass.New()

class itkBinaryThresholdImageFilterIF2IF2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF2IF2):
    r"""Proxy of C++ itkBinaryThresholdImageFilterIF2IF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterIF2IF2_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterIF2IF2_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::BinaryThreshold< float,float >
        GetFunctor(self) -> itk::Functor::BinaryThreshold< float,float > const &
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::BinaryThreshold< float,float > const &

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterIF2IF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterIF2IF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterIF2IF2_Superclass

        Create a new object of the class itkBinaryThresholdImageFilterIF2IF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterIF2IF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterIF2IF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterIF2IF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterIF2IF2_Superclass in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_Superclass_swigregister(itkBinaryThresholdImageFilterIF2IF2_Superclass)

def itkBinaryThresholdImageFilterIF2ISS2_Superclass_New():
    return itkBinaryThresholdImageFilterIF2ISS2_Superclass.New()

class itkBinaryThresholdImageFilterIF2ISS2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF2ISS2):
    r"""Proxy of C++ itkBinaryThresholdImageFilterIF2ISS2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterIF2ISS2_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterIF2ISS2_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::BinaryThreshold< float,short >
        GetFunctor(self) -> itk::Functor::BinaryThreshold< float,short > const &
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::BinaryThreshold< float,short > const &

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterIF2ISS2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterIF2ISS2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterIF2ISS2_Superclass

        Create a new object of the class itkBinaryThresholdImageFilterIF2ISS2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterIF2ISS2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterIF2ISS2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterIF2ISS2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterIF2ISS2_Superclass in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_Superclass_swigregister(itkBinaryThresholdImageFilterIF2ISS2_Superclass)

def itkBinaryThresholdImageFilterIF2IUC2_Superclass_New():
    return itkBinaryThresholdImageFilterIF2IUC2_Superclass.New()

class itkBinaryThresholdImageFilterIF2IUC2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF2IUC2):
    r"""Proxy of C++ itkBinaryThresholdImageFilterIF2IUC2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterIF2IUC2_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterIF2IUC2_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::BinaryThreshold< float,unsigned char >
        GetFunctor(self) -> itk::Functor::BinaryThreshold< float,unsigned char > const &
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::BinaryThreshold< float,unsigned char > const &

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterIF2IUC2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterIF2IUC2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterIF2IUC2_Superclass

        Create a new object of the class itkBinaryThresholdImageFilterIF2IUC2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterIF2IUC2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterIF2IUC2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterIF2IUC2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterIF2IUC2_Superclass in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_Superclass_swigregister(itkBinaryThresholdImageFilterIF2IUC2_Superclass)

def itkBinaryThresholdImageFilterIF3IF3_Superclass_New():
    return itkBinaryThresholdImageFilterIF3IF3_Superclass.New()

class itkBinaryThresholdImageFilterIF3IF3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF3IF3):
    r"""Proxy of C++ itkBinaryThresholdImageFilterIF3IF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterIF3IF3_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterIF3IF3_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::BinaryThreshold< float,float >
        GetFunctor(self) -> itk::Functor::BinaryThreshold< float,float > const &
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::BinaryThreshold< float,float > const &

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterIF3IF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterIF3IF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterIF3IF3_Superclass

        Create a new object of the class itkBinaryThresholdImageFilterIF3IF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterIF3IF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterIF3IF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterIF3IF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterIF3IF3_Superclass in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_Superclass_swigregister(itkBinaryThresholdImageFilterIF3IF3_Superclass)

def itkBinaryThresholdImageFilterIF3ISS3_Superclass_New():
    return itkBinaryThresholdImageFilterIF3ISS3_Superclass.New()

class itkBinaryThresholdImageFilterIF3ISS3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF3ISS3):
    r"""Proxy of C++ itkBinaryThresholdImageFilterIF3ISS3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterIF3ISS3_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterIF3ISS3_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::BinaryThreshold< float,short >
        GetFunctor(self) -> itk::Functor::BinaryThreshold< float,short > const &
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::BinaryThreshold< float,short > const &

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterIF3ISS3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterIF3ISS3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterIF3ISS3_Superclass

        Create a new object of the class itkBinaryThresholdImageFilterIF3ISS3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterIF3ISS3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterIF3ISS3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterIF3ISS3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterIF3ISS3_Superclass in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_Superclass_swigregister(itkBinaryThresholdImageFilterIF3ISS3_Superclass)

def itkBinaryThresholdImageFilterIF3IUC3_Superclass_New():
    return itkBinaryThresholdImageFilterIF3IUC3_Superclass.New()

class itkBinaryThresholdImageFilterIF3IUC3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF3IUC3):
    r"""Proxy of C++ itkBinaryThresholdImageFilterIF3IUC3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterIF3IUC3_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterIF3IUC3_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::BinaryThreshold< float,unsigned char >
        GetFunctor(self) -> itk::Functor::BinaryThreshold< float,unsigned char > const &
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::BinaryThreshold< float,unsigned char > const &

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterIF3IUC3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterIF3IUC3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterIF3IUC3_Superclass

        Create a new object of the class itkBinaryThresholdImageFilterIF3IUC3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterIF3IUC3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterIF3IUC3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterIF3IUC3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterIF3IUC3_Superclass in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_Superclass_swigregister(itkBinaryThresholdImageFilterIF3IUC3_Superclass)

def itkBinaryThresholdImageFilterISS2ISS2_Superclass_New():
    return itkBinaryThresholdImageFilterISS2ISS2_Superclass.New()

class itkBinaryThresholdImageFilterISS2ISS2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS2ISS2):
    r"""Proxy of C++ itkBinaryThresholdImageFilterISS2ISS2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterISS2ISS2_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterISS2ISS2_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::BinaryThreshold< short,short >
        GetFunctor(self) -> itk::Functor::BinaryThreshold< short,short > const &
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::BinaryThreshold< short,short > const &

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterISS2ISS2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterISS2ISS2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterISS2ISS2_Superclass

        Create a new object of the class itkBinaryThresholdImageFilterISS2ISS2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterISS2ISS2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterISS2ISS2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterISS2ISS2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterISS2ISS2_Superclass in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_Superclass_swigregister(itkBinaryThresholdImageFilterISS2ISS2_Superclass)

def itkBinaryThresholdImageFilterISS2IUC2_Superclass_New():
    return itkBinaryThresholdImageFilterISS2IUC2_Superclass.New()

class itkBinaryThresholdImageFilterISS2IUC2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS2IUC2):
    r"""Proxy of C++ itkBinaryThresholdImageFilterISS2IUC2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterISS2IUC2_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterISS2IUC2_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::BinaryThreshold< short,unsigned char >
        GetFunctor(self) -> itk::Functor::BinaryThreshold< short,unsigned char > const &
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::BinaryThreshold< short,unsigned char > const &

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterISS2IUC2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterISS2IUC2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterISS2IUC2_Superclass

        Create a new object of the class itkBinaryThresholdImageFilterISS2IUC2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterISS2IUC2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterISS2IUC2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterISS2IUC2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterISS2IUC2_Superclass in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_Superclass_swigregister(itkBinaryThresholdImageFilterISS2IUC2_Superclass)

def itkBinaryThresholdImageFilterISS3ISS3_Superclass_New():
    return itkBinaryThresholdImageFilterISS3ISS3_Superclass.New()

class itkBinaryThresholdImageFilterISS3ISS3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS3ISS3):
    r"""Proxy of C++ itkBinaryThresholdImageFilterISS3ISS3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterISS3ISS3_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterISS3ISS3_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::BinaryThreshold< short,short >
        GetFunctor(self) -> itk::Functor::BinaryThreshold< short,short > const &
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::BinaryThreshold< short,short > const &

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterISS3ISS3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterISS3ISS3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterISS3ISS3_Superclass

        Create a new object of the class itkBinaryThresholdImageFilterISS3ISS3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterISS3ISS3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterISS3ISS3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterISS3ISS3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterISS3ISS3_Superclass in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_Superclass_swigregister(itkBinaryThresholdImageFilterISS3ISS3_Superclass)

def itkBinaryThresholdImageFilterISS3IUC3_Superclass_New():
    return itkBinaryThresholdImageFilterISS3IUC3_Superclass.New()

class itkBinaryThresholdImageFilterISS3IUC3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS3IUC3):
    r"""Proxy of C++ itkBinaryThresholdImageFilterISS3IUC3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterISS3IUC3_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterISS3IUC3_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::BinaryThreshold< short,unsigned char >
        GetFunctor(self) -> itk::Functor::BinaryThreshold< short,unsigned char > const &
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::BinaryThreshold< short,unsigned char > const &

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterISS3IUC3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterISS3IUC3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterISS3IUC3_Superclass

        Create a new object of the class itkBinaryThresholdImageFilterISS3IUC3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterISS3IUC3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterISS3IUC3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterISS3IUC3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterISS3IUC3_Superclass in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_Superclass_swigregister(itkBinaryThresholdImageFilterISS3IUC3_Superclass)

def itkBinaryThresholdImageFilterIUC2IUC2_Superclass_New():
    return itkBinaryThresholdImageFilterIUC2IUC2_Superclass.New()

class itkBinaryThresholdImageFilterIUC2IUC2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC2IUC2):
    r"""Proxy of C++ itkBinaryThresholdImageFilterIUC2IUC2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterIUC2IUC2_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterIUC2IUC2_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::BinaryThreshold< unsigned char,unsigned char >
        GetFunctor(self) -> itk::Functor::BinaryThreshold< unsigned char,unsigned char > const &
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::BinaryThreshold< unsigned char,unsigned char > const &

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterIUC2IUC2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterIUC2IUC2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterIUC2IUC2_Superclass

        Create a new object of the class itkBinaryThresholdImageFilterIUC2IUC2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterIUC2IUC2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterIUC2IUC2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterIUC2IUC2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterIUC2IUC2_Superclass in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_Superclass_swigregister(itkBinaryThresholdImageFilterIUC2IUC2_Superclass)

def itkBinaryThresholdImageFilterIUC3IUC3_Superclass_New():
    return itkBinaryThresholdImageFilterIUC3IUC3_Superclass.New()

class itkBinaryThresholdImageFilterIUC3IUC3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC3IUC3):
    r"""Proxy of C++ itkBinaryThresholdImageFilterIUC3IUC3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterIUC3IUC3_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterIUC3IUC3_Superclass_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::BinaryThreshold< unsigned char,unsigned char >
        GetFunctor(self) -> itk::Functor::BinaryThreshold< unsigned char,unsigned char > const &
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::BinaryThreshold< unsigned char,unsigned char > const &

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterIUC3IUC3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterIUC3IUC3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterIUC3IUC3_Superclass

        Create a new object of the class itkBinaryThresholdImageFilterIUC3IUC3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterIUC3IUC3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterIUC3IUC3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterIUC3IUC3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterIUC3IUC3_Superclass in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_Superclass_swigregister(itkBinaryThresholdImageFilterIUC3IUC3_Superclass)

def itkBinaryThresholdImageFilterIF2IF2_New():
    return itkBinaryThresholdImageFilterIF2IF2.New()

class itkBinaryThresholdImageFilterIF2IF2(itkBinaryThresholdImageFilterIF2IF2_Superclass):
    r"""Proxy of C++ itkBinaryThresholdImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterIF2IF2_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterIF2IF2_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> float const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> float const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_GetInsideValue(self)

    def SetUpperThreshold(self, threshold):
        r"""
        SetUpperThreshold(self, threshold)

        Parameters
        ----------
        threshold: float const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_SetUpperThreshold(self, threshold)

    def SetUpperThresholdInput(self, arg0):
        r"""
        SetUpperThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorF const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_SetUpperThresholdInput(self, arg0)

    def SetLowerThreshold(self, threshold):
        r"""
        SetLowerThreshold(self, threshold)

        Parameters
        ----------
        threshold: float const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_SetLowerThreshold(self, threshold)

    def SetLowerThresholdInput(self, arg0):
        r"""
        SetLowerThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorF const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_SetLowerThresholdInput(self, arg0)

    def GetUpperThreshold(self):
        r"""GetUpperThreshold(self) -> float"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_GetUpperThreshold(self)

    def GetUpperThresholdInput(self, *args):
        r"""
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_GetUpperThresholdInput(self, *args)

    def GetLowerThreshold(self):
        r"""GetLowerThreshold(self) -> float"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_GetLowerThreshold(self)

    def GetLowerThresholdInput(self, *args):
        r"""
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_GetLowerThresholdInput(self, *args)
    OutputEqualityComparableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_OutputEqualityComparableCheck
    
    InputPixelTypeComparable = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_InputPixelTypeComparable
    
    InputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterIF2IF2

        Create a new object of the class itkBinaryThresholdImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterIF2IF2 in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IF2_swigregister(itkBinaryThresholdImageFilterIF2IF2)

def itkBinaryThresholdImageFilterIF2ISS2_New():
    return itkBinaryThresholdImageFilterIF2ISS2.New()

class itkBinaryThresholdImageFilterIF2ISS2(itkBinaryThresholdImageFilterIF2ISS2_Superclass):
    r"""Proxy of C++ itkBinaryThresholdImageFilterIF2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterIF2ISS2_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterIF2ISS2_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> short const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> short const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_GetInsideValue(self)

    def SetUpperThreshold(self, threshold):
        r"""
        SetUpperThreshold(self, threshold)

        Parameters
        ----------
        threshold: float const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_SetUpperThreshold(self, threshold)

    def SetUpperThresholdInput(self, arg0):
        r"""
        SetUpperThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorF const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_SetUpperThresholdInput(self, arg0)

    def SetLowerThreshold(self, threshold):
        r"""
        SetLowerThreshold(self, threshold)

        Parameters
        ----------
        threshold: float const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_SetLowerThreshold(self, threshold)

    def SetLowerThresholdInput(self, arg0):
        r"""
        SetLowerThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorF const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_SetLowerThresholdInput(self, arg0)

    def GetUpperThreshold(self):
        r"""GetUpperThreshold(self) -> float"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_GetUpperThreshold(self)

    def GetUpperThresholdInput(self, *args):
        r"""
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_GetUpperThresholdInput(self, *args)

    def GetLowerThreshold(self):
        r"""GetLowerThreshold(self) -> float"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_GetLowerThreshold(self)

    def GetLowerThresholdInput(self, *args):
        r"""
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_GetLowerThresholdInput(self, *args)
    OutputEqualityComparableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_OutputEqualityComparableCheck
    
    InputPixelTypeComparable = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_InputPixelTypeComparable
    
    InputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterIF2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterIF2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterIF2ISS2

        Create a new object of the class itkBinaryThresholdImageFilterIF2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterIF2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterIF2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterIF2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterIF2ISS2 in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2ISS2_swigregister(itkBinaryThresholdImageFilterIF2ISS2)

def itkBinaryThresholdImageFilterIF2IUC2_New():
    return itkBinaryThresholdImageFilterIF2IUC2.New()

class itkBinaryThresholdImageFilterIF2IUC2(itkBinaryThresholdImageFilterIF2IUC2_Superclass):
    r"""Proxy of C++ itkBinaryThresholdImageFilterIF2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterIF2IUC2_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterIF2IUC2_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_GetInsideValue(self)

    def SetUpperThreshold(self, threshold):
        r"""
        SetUpperThreshold(self, threshold)

        Parameters
        ----------
        threshold: float const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_SetUpperThreshold(self, threshold)

    def SetUpperThresholdInput(self, arg0):
        r"""
        SetUpperThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorF const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_SetUpperThresholdInput(self, arg0)

    def SetLowerThreshold(self, threshold):
        r"""
        SetLowerThreshold(self, threshold)

        Parameters
        ----------
        threshold: float const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_SetLowerThreshold(self, threshold)

    def SetLowerThresholdInput(self, arg0):
        r"""
        SetLowerThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorF const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_SetLowerThresholdInput(self, arg0)

    def GetUpperThreshold(self):
        r"""GetUpperThreshold(self) -> float"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_GetUpperThreshold(self)

    def GetUpperThresholdInput(self, *args):
        r"""
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_GetUpperThresholdInput(self, *args)

    def GetLowerThreshold(self):
        r"""GetLowerThreshold(self) -> float"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_GetLowerThreshold(self)

    def GetLowerThresholdInput(self, *args):
        r"""
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_GetLowerThresholdInput(self, *args)
    OutputEqualityComparableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_OutputEqualityComparableCheck
    
    InputPixelTypeComparable = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_InputPixelTypeComparable
    
    InputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterIF2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterIF2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterIF2IUC2

        Create a new object of the class itkBinaryThresholdImageFilterIF2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterIF2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterIF2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterIF2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterIF2IUC2 in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF2IUC2_swigregister(itkBinaryThresholdImageFilterIF2IUC2)

def itkBinaryThresholdImageFilterIF3IF3_New():
    return itkBinaryThresholdImageFilterIF3IF3.New()

class itkBinaryThresholdImageFilterIF3IF3(itkBinaryThresholdImageFilterIF3IF3_Superclass):
    r"""Proxy of C++ itkBinaryThresholdImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterIF3IF3_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterIF3IF3_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> float const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> float const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_GetInsideValue(self)

    def SetUpperThreshold(self, threshold):
        r"""
        SetUpperThreshold(self, threshold)

        Parameters
        ----------
        threshold: float const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_SetUpperThreshold(self, threshold)

    def SetUpperThresholdInput(self, arg0):
        r"""
        SetUpperThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorF const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_SetUpperThresholdInput(self, arg0)

    def SetLowerThreshold(self, threshold):
        r"""
        SetLowerThreshold(self, threshold)

        Parameters
        ----------
        threshold: float const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_SetLowerThreshold(self, threshold)

    def SetLowerThresholdInput(self, arg0):
        r"""
        SetLowerThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorF const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_SetLowerThresholdInput(self, arg0)

    def GetUpperThreshold(self):
        r"""GetUpperThreshold(self) -> float"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_GetUpperThreshold(self)

    def GetUpperThresholdInput(self, *args):
        r"""
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_GetUpperThresholdInput(self, *args)

    def GetLowerThreshold(self):
        r"""GetLowerThreshold(self) -> float"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_GetLowerThreshold(self)

    def GetLowerThresholdInput(self, *args):
        r"""
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_GetLowerThresholdInput(self, *args)
    OutputEqualityComparableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_OutputEqualityComparableCheck
    
    InputPixelTypeComparable = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_InputPixelTypeComparable
    
    InputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterIF3IF3

        Create a new object of the class itkBinaryThresholdImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterIF3IF3 in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IF3_swigregister(itkBinaryThresholdImageFilterIF3IF3)

def itkBinaryThresholdImageFilterIF3ISS3_New():
    return itkBinaryThresholdImageFilterIF3ISS3.New()

class itkBinaryThresholdImageFilterIF3ISS3(itkBinaryThresholdImageFilterIF3ISS3_Superclass):
    r"""Proxy of C++ itkBinaryThresholdImageFilterIF3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterIF3ISS3_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterIF3ISS3_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> short const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> short const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_GetInsideValue(self)

    def SetUpperThreshold(self, threshold):
        r"""
        SetUpperThreshold(self, threshold)

        Parameters
        ----------
        threshold: float const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_SetUpperThreshold(self, threshold)

    def SetUpperThresholdInput(self, arg0):
        r"""
        SetUpperThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorF const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_SetUpperThresholdInput(self, arg0)

    def SetLowerThreshold(self, threshold):
        r"""
        SetLowerThreshold(self, threshold)

        Parameters
        ----------
        threshold: float const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_SetLowerThreshold(self, threshold)

    def SetLowerThresholdInput(self, arg0):
        r"""
        SetLowerThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorF const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_SetLowerThresholdInput(self, arg0)

    def GetUpperThreshold(self):
        r"""GetUpperThreshold(self) -> float"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_GetUpperThreshold(self)

    def GetUpperThresholdInput(self, *args):
        r"""
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_GetUpperThresholdInput(self, *args)

    def GetLowerThreshold(self):
        r"""GetLowerThreshold(self) -> float"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_GetLowerThreshold(self)

    def GetLowerThresholdInput(self, *args):
        r"""
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_GetLowerThresholdInput(self, *args)
    OutputEqualityComparableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_OutputEqualityComparableCheck
    
    InputPixelTypeComparable = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_InputPixelTypeComparable
    
    InputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterIF3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterIF3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterIF3ISS3

        Create a new object of the class itkBinaryThresholdImageFilterIF3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterIF3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterIF3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterIF3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterIF3ISS3 in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3ISS3_swigregister(itkBinaryThresholdImageFilterIF3ISS3)

def itkBinaryThresholdImageFilterIF3IUC3_New():
    return itkBinaryThresholdImageFilterIF3IUC3.New()

class itkBinaryThresholdImageFilterIF3IUC3(itkBinaryThresholdImageFilterIF3IUC3_Superclass):
    r"""Proxy of C++ itkBinaryThresholdImageFilterIF3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterIF3IUC3_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterIF3IUC3_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_GetInsideValue(self)

    def SetUpperThreshold(self, threshold):
        r"""
        SetUpperThreshold(self, threshold)

        Parameters
        ----------
        threshold: float const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_SetUpperThreshold(self, threshold)

    def SetUpperThresholdInput(self, arg0):
        r"""
        SetUpperThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorF const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_SetUpperThresholdInput(self, arg0)

    def SetLowerThreshold(self, threshold):
        r"""
        SetLowerThreshold(self, threshold)

        Parameters
        ----------
        threshold: float const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_SetLowerThreshold(self, threshold)

    def SetLowerThresholdInput(self, arg0):
        r"""
        SetLowerThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorF const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_SetLowerThresholdInput(self, arg0)

    def GetUpperThreshold(self):
        r"""GetUpperThreshold(self) -> float"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_GetUpperThreshold(self)

    def GetUpperThresholdInput(self, *args):
        r"""
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_GetUpperThresholdInput(self, *args)

    def GetLowerThreshold(self):
        r"""GetLowerThreshold(self) -> float"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_GetLowerThreshold(self)

    def GetLowerThresholdInput(self, *args):
        r"""
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorF
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_GetLowerThresholdInput(self, *args)
    OutputEqualityComparableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_OutputEqualityComparableCheck
    
    InputPixelTypeComparable = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_InputPixelTypeComparable
    
    InputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterIF3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterIF3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterIF3IUC3

        Create a new object of the class itkBinaryThresholdImageFilterIF3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterIF3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterIF3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterIF3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterIF3IUC3 in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIF3IUC3_swigregister(itkBinaryThresholdImageFilterIF3IUC3)

def itkBinaryThresholdImageFilterISS2ISS2_New():
    return itkBinaryThresholdImageFilterISS2ISS2.New()

class itkBinaryThresholdImageFilterISS2ISS2(itkBinaryThresholdImageFilterISS2ISS2_Superclass):
    r"""Proxy of C++ itkBinaryThresholdImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterISS2ISS2_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterISS2ISS2_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> short const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> short const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_GetInsideValue(self)

    def SetUpperThreshold(self, threshold):
        r"""
        SetUpperThreshold(self, threshold)

        Parameters
        ----------
        threshold: short const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_SetUpperThreshold(self, threshold)

    def SetUpperThresholdInput(self, arg0):
        r"""
        SetUpperThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorSS const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_SetUpperThresholdInput(self, arg0)

    def SetLowerThreshold(self, threshold):
        r"""
        SetLowerThreshold(self, threshold)

        Parameters
        ----------
        threshold: short const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_SetLowerThreshold(self, threshold)

    def SetLowerThresholdInput(self, arg0):
        r"""
        SetLowerThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorSS const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_SetLowerThresholdInput(self, arg0)

    def GetUpperThreshold(self):
        r"""GetUpperThreshold(self) -> short"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_GetUpperThreshold(self)

    def GetUpperThresholdInput(self, *args):
        r"""
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorSS
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorSS
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_GetUpperThresholdInput(self, *args)

    def GetLowerThreshold(self):
        r"""GetLowerThreshold(self) -> short"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_GetLowerThreshold(self)

    def GetLowerThresholdInput(self, *args):
        r"""
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorSS
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorSS
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_GetLowerThresholdInput(self, *args)
    OutputEqualityComparableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_OutputEqualityComparableCheck
    
    InputPixelTypeComparable = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_InputPixelTypeComparable
    
    InputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterISS2ISS2

        Create a new object of the class itkBinaryThresholdImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterISS2ISS2 in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2ISS2_swigregister(itkBinaryThresholdImageFilterISS2ISS2)

def itkBinaryThresholdImageFilterISS2IUC2_New():
    return itkBinaryThresholdImageFilterISS2IUC2.New()

class itkBinaryThresholdImageFilterISS2IUC2(itkBinaryThresholdImageFilterISS2IUC2_Superclass):
    r"""Proxy of C++ itkBinaryThresholdImageFilterISS2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterISS2IUC2_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterISS2IUC2_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_GetInsideValue(self)

    def SetUpperThreshold(self, threshold):
        r"""
        SetUpperThreshold(self, threshold)

        Parameters
        ----------
        threshold: short const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_SetUpperThreshold(self, threshold)

    def SetUpperThresholdInput(self, arg0):
        r"""
        SetUpperThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorSS const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_SetUpperThresholdInput(self, arg0)

    def SetLowerThreshold(self, threshold):
        r"""
        SetLowerThreshold(self, threshold)

        Parameters
        ----------
        threshold: short const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_SetLowerThreshold(self, threshold)

    def SetLowerThresholdInput(self, arg0):
        r"""
        SetLowerThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorSS const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_SetLowerThresholdInput(self, arg0)

    def GetUpperThreshold(self):
        r"""GetUpperThreshold(self) -> short"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_GetUpperThreshold(self)

    def GetUpperThresholdInput(self, *args):
        r"""
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorSS
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorSS
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_GetUpperThresholdInput(self, *args)

    def GetLowerThreshold(self):
        r"""GetLowerThreshold(self) -> short"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_GetLowerThreshold(self)

    def GetLowerThresholdInput(self, *args):
        r"""
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorSS
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorSS
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_GetLowerThresholdInput(self, *args)
    OutputEqualityComparableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_OutputEqualityComparableCheck
    
    InputPixelTypeComparable = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_InputPixelTypeComparable
    
    InputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterISS2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterISS2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterISS2IUC2

        Create a new object of the class itkBinaryThresholdImageFilterISS2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterISS2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterISS2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterISS2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterISS2IUC2 in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS2IUC2_swigregister(itkBinaryThresholdImageFilterISS2IUC2)

def itkBinaryThresholdImageFilterISS3ISS3_New():
    return itkBinaryThresholdImageFilterISS3ISS3.New()

class itkBinaryThresholdImageFilterISS3ISS3(itkBinaryThresholdImageFilterISS3ISS3_Superclass):
    r"""Proxy of C++ itkBinaryThresholdImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterISS3ISS3_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterISS3ISS3_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> short const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> short const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_GetInsideValue(self)

    def SetUpperThreshold(self, threshold):
        r"""
        SetUpperThreshold(self, threshold)

        Parameters
        ----------
        threshold: short const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_SetUpperThreshold(self, threshold)

    def SetUpperThresholdInput(self, arg0):
        r"""
        SetUpperThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorSS const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_SetUpperThresholdInput(self, arg0)

    def SetLowerThreshold(self, threshold):
        r"""
        SetLowerThreshold(self, threshold)

        Parameters
        ----------
        threshold: short const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_SetLowerThreshold(self, threshold)

    def SetLowerThresholdInput(self, arg0):
        r"""
        SetLowerThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorSS const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_SetLowerThresholdInput(self, arg0)

    def GetUpperThreshold(self):
        r"""GetUpperThreshold(self) -> short"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_GetUpperThreshold(self)

    def GetUpperThresholdInput(self, *args):
        r"""
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorSS
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorSS
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_GetUpperThresholdInput(self, *args)

    def GetLowerThreshold(self):
        r"""GetLowerThreshold(self) -> short"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_GetLowerThreshold(self)

    def GetLowerThresholdInput(self, *args):
        r"""
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorSS
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorSS
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_GetLowerThresholdInput(self, *args)
    OutputEqualityComparableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_OutputEqualityComparableCheck
    
    InputPixelTypeComparable = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_InputPixelTypeComparable
    
    InputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterISS3ISS3

        Create a new object of the class itkBinaryThresholdImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterISS3ISS3 in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3ISS3_swigregister(itkBinaryThresholdImageFilterISS3ISS3)

def itkBinaryThresholdImageFilterISS3IUC3_New():
    return itkBinaryThresholdImageFilterISS3IUC3.New()

class itkBinaryThresholdImageFilterISS3IUC3(itkBinaryThresholdImageFilterISS3IUC3_Superclass):
    r"""Proxy of C++ itkBinaryThresholdImageFilterISS3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterISS3IUC3_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterISS3IUC3_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_GetInsideValue(self)

    def SetUpperThreshold(self, threshold):
        r"""
        SetUpperThreshold(self, threshold)

        Parameters
        ----------
        threshold: short const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_SetUpperThreshold(self, threshold)

    def SetUpperThresholdInput(self, arg0):
        r"""
        SetUpperThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorSS const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_SetUpperThresholdInput(self, arg0)

    def SetLowerThreshold(self, threshold):
        r"""
        SetLowerThreshold(self, threshold)

        Parameters
        ----------
        threshold: short const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_SetLowerThreshold(self, threshold)

    def SetLowerThresholdInput(self, arg0):
        r"""
        SetLowerThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorSS const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_SetLowerThresholdInput(self, arg0)

    def GetUpperThreshold(self):
        r"""GetUpperThreshold(self) -> short"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_GetUpperThreshold(self)

    def GetUpperThresholdInput(self, *args):
        r"""
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorSS
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorSS
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_GetUpperThresholdInput(self, *args)

    def GetLowerThreshold(self):
        r"""GetLowerThreshold(self) -> short"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_GetLowerThreshold(self)

    def GetLowerThresholdInput(self, *args):
        r"""
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorSS
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorSS
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_GetLowerThresholdInput(self, *args)
    OutputEqualityComparableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_OutputEqualityComparableCheck
    
    InputPixelTypeComparable = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_InputPixelTypeComparable
    
    InputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterISS3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterISS3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterISS3IUC3

        Create a new object of the class itkBinaryThresholdImageFilterISS3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterISS3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterISS3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterISS3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterISS3IUC3 in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterISS3IUC3_swigregister(itkBinaryThresholdImageFilterISS3IUC3)

def itkBinaryThresholdImageFilterIUC2IUC2_New():
    return itkBinaryThresholdImageFilterIUC2IUC2.New()

class itkBinaryThresholdImageFilterIUC2IUC2(itkBinaryThresholdImageFilterIUC2IUC2_Superclass):
    r"""Proxy of C++ itkBinaryThresholdImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterIUC2IUC2_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterIUC2IUC2_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_GetInsideValue(self)

    def SetUpperThreshold(self, threshold):
        r"""
        SetUpperThreshold(self, threshold)

        Parameters
        ----------
        threshold: unsigned char const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_SetUpperThreshold(self, threshold)

    def SetUpperThresholdInput(self, arg0):
        r"""
        SetUpperThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorUC const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_SetUpperThresholdInput(self, arg0)

    def SetLowerThreshold(self, threshold):
        r"""
        SetLowerThreshold(self, threshold)

        Parameters
        ----------
        threshold: unsigned char const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_SetLowerThreshold(self, threshold)

    def SetLowerThresholdInput(self, arg0):
        r"""
        SetLowerThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorUC const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_SetLowerThresholdInput(self, arg0)

    def GetUpperThreshold(self):
        r"""GetUpperThreshold(self) -> unsigned char"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_GetUpperThreshold(self)

    def GetUpperThresholdInput(self, *args):
        r"""
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorUC
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorUC
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_GetUpperThresholdInput(self, *args)

    def GetLowerThreshold(self):
        r"""GetLowerThreshold(self) -> unsigned char"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_GetLowerThreshold(self)

    def GetLowerThresholdInput(self, *args):
        r"""
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorUC
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorUC
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_GetLowerThresholdInput(self, *args)
    OutputEqualityComparableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_OutputEqualityComparableCheck
    
    InputPixelTypeComparable = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_InputPixelTypeComparable
    
    InputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterIUC2IUC2

        Create a new object of the class itkBinaryThresholdImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterIUC2IUC2 in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC2IUC2_swigregister(itkBinaryThresholdImageFilterIUC2IUC2)

def itkBinaryThresholdImageFilterIUC3IUC3_New():
    return itkBinaryThresholdImageFilterIUC3IUC3.New()

class itkBinaryThresholdImageFilterIUC3IUC3(itkBinaryThresholdImageFilterIUC3IUC3_Superclass):
    r"""Proxy of C++ itkBinaryThresholdImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryThresholdImageFilterIUC3IUC3_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryThresholdImageFilterIUC3IUC3_Pointer"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char const &"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_GetInsideValue(self)

    def SetUpperThreshold(self, threshold):
        r"""
        SetUpperThreshold(self, threshold)

        Parameters
        ----------
        threshold: unsigned char const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_SetUpperThreshold(self, threshold)

    def SetUpperThresholdInput(self, arg0):
        r"""
        SetUpperThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorUC const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_SetUpperThresholdInput(self, arg0)

    def SetLowerThreshold(self, threshold):
        r"""
        SetLowerThreshold(self, threshold)

        Parameters
        ----------
        threshold: unsigned char const

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_SetLowerThreshold(self, threshold)

    def SetLowerThresholdInput(self, arg0):
        r"""
        SetLowerThresholdInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorUC const *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_SetLowerThresholdInput(self, arg0)

    def GetUpperThreshold(self):
        r"""GetUpperThreshold(self) -> unsigned char"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_GetUpperThreshold(self)

    def GetUpperThresholdInput(self, *args):
        r"""
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorUC
        GetUpperThresholdInput(self) -> itkSimpleDataObjectDecoratorUC
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_GetUpperThresholdInput(self, *args)

    def GetLowerThreshold(self):
        r"""GetLowerThreshold(self) -> unsigned char"""
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_GetLowerThreshold(self)

    def GetLowerThresholdInput(self, *args):
        r"""
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorUC
        GetLowerThresholdInput(self) -> itkSimpleDataObjectDecoratorUC
        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_GetLowerThresholdInput(self, *args)
    OutputEqualityComparableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_OutputEqualityComparableCheck
    
    InputPixelTypeComparable = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_InputPixelTypeComparable
    
    InputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkBinaryThresholdImageFilterPython.delete_itkBinaryThresholdImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryThresholdImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryThresholdImageFilterIUC3IUC3

        Create a new object of the class itkBinaryThresholdImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryThresholdImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryThresholdImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryThresholdImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryThresholdImageFilterIUC3IUC3 in _itkBinaryThresholdImageFilterPython:
_itkBinaryThresholdImageFilterPython.itkBinaryThresholdImageFilterIUC3IUC3_swigregister(itkBinaryThresholdImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def binary_threshold_image_filter(*args: itkt.ImageLike,  outside_value: float=..., inside_value: float=..., upper_threshold: float=..., upper_threshold_input=..., lower_threshold: float=..., lower_threshold_input=..., functor=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for BinaryThresholdImageFilter"""
    import itk

    kwarg_typehints = { 'outside_value':outside_value,'inside_value':inside_value,'upper_threshold':upper_threshold,'upper_threshold_input':upper_threshold_input,'lower_threshold':lower_threshold,'lower_threshold_input':lower_threshold_input,'functor':functor }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.BinaryThresholdImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def binary_threshold_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKThresholding.BinaryThresholdImageFilter
    binary_threshold_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    binary_threshold_image_filter.__doc__ = filter_object.__doc__

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def unary_functor_image_filter(*args: itkt.ImageLike,  functor=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for UnaryFunctorImageFilter"""
    import itk

    kwarg_typehints = { 'functor':functor }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.UnaryFunctorImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def unary_functor_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKThresholding.UnaryFunctorImageFilter
    unary_functor_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    unary_functor_image_filter.__doc__ = filter_object.__doc__



